@@ -33,10 +33,16 @@
 #  define VTKPVCLIENTWEB_DEPRECATED_NO_EXPORT VTKPVCLIENTWEB_NO_EXPORT VTKPVCLIENTWEB_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef VTKPVCLIENTWEB_NO_DEPRECATED
 #    define VTKPVCLIENTWEB_NO_DEPRECATED
 #  endif
 #endif
 
+/* VTK-HeaderTest-Exclude: vtkPVClientWebModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
 #endif /* VTKPVCLIENTWEB_EXPORT_H */
